@@ -293,8 +293,8 @@ class SqsClient extends AbstractApi
      *
      * @param array{
      *   QueueName: string,
-     *   Attributes?: null|array<QueueAttributeName::*, string>,
-     *   tags?: null|array<string, string>,
+     *   Attributes?: array<QueueAttributeName::*, string>|null,
+     *   tags?: array<string, string>|null,
      *   '@region'?: string|null,
      * }|CreateQueueRequest $input
      *
@@ -478,7 +478,7 @@ class SqsClient extends AbstractApi
      *
      * @param array{
      *   QueueUrl: string,
-     *   AttributeNames?: null|array<QueueAttributeName::*>,
+     *   AttributeNames?: array<QueueAttributeName::*>|null,
      *   '@region'?: string|null,
      * }|GetQueueAttributesRequest $input
      *
@@ -520,7 +520,7 @@ class SqsClient extends AbstractApi
      *
      * @param array{
      *   QueueName: string,
-     *   QueueOwnerAWSAccountId?: null|string,
+     *   QueueOwnerAWSAccountId?: string|null,
      *   '@region'?: string|null,
      * }|GetQueueUrlRequest $input
      *
@@ -563,9 +563,9 @@ class SqsClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#listqueues
      *
      * @param array{
-     *   QueueNamePrefix?: null|string,
-     *   NextToken?: null|string,
-     *   MaxResults?: null|int,
+     *   QueueNamePrefix?: string|null,
+     *   NextToken?: string|null,
+     *   MaxResults?: int|null,
      *   '@region'?: string|null,
      * }|ListQueuesRequest $input
      *
@@ -634,7 +634,7 @@ class SqsClient extends AbstractApi
      *
      * @param array{
      *   QueueName: string,
-     *   QueueOwnerAWSAccountId?: null|string,
+     *   QueueOwnerAWSAccountId?: string|null,
      *   '@region'?: string|null,
      * }|GetQueueUrlRequest $input
      */
@@ -690,13 +690,13 @@ class SqsClient extends AbstractApi
      *
      * @param array{
      *   QueueUrl: string,
-     *   AttributeNames?: null|array<MessageSystemAttributeName::*>,
-     *   MessageSystemAttributeNames?: null|array<MessageSystemAttributeName::*>,
-     *   MessageAttributeNames?: null|string[],
-     *   MaxNumberOfMessages?: null|int,
-     *   VisibilityTimeout?: null|int,
-     *   WaitTimeSeconds?: null|int,
-     *   ReceiveRequestAttemptId?: null|string,
+     *   AttributeNames?: array<MessageSystemAttributeName::*>|null,
+     *   MessageSystemAttributeNames?: array<MessageSystemAttributeName::*>|null,
+     *   MessageAttributeNames?: string[]|null,
+     *   MaxNumberOfMessages?: int|null,
+     *   VisibilityTimeout?: int|null,
+     *   WaitTimeSeconds?: int|null,
+     *   ReceiveRequestAttemptId?: string|null,
      *   '@region'?: string|null,
      * }|ReceiveMessageRequest $input
      *
@@ -744,9 +744,8 @@ class SqsClient extends AbstractApi
      * !
      * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
      * !
-     * ! Amazon SQS does not throw an exception or completely reject the message if it contains invalid characters. Instead,
-     * ! it replaces those invalid characters with U+FFFD before storing the message in the queue, as long as the message
-     * ! body contains at least one valid character.
+     * ! If a message contains characters outside the allowed set, Amazon SQS rejects the message and returns an
+     * ! InvalidMessageContents error. Ensure that your message body includes only valid characters to avoid this exception.
      *
      * [^1]: http://www.w3.org/TR/REC-xml/#charsets
      *
@@ -756,11 +755,11 @@ class SqsClient extends AbstractApi
      * @param array{
      *   QueueUrl: string,
      *   MessageBody: string,
-     *   DelaySeconds?: null|int,
-     *   MessageAttributes?: null|array<string, MessageAttributeValue|array>,
-     *   MessageSystemAttributes?: null|array<MessageSystemAttributeNameForSends::*, MessageSystemAttributeValue|array>,
-     *   MessageDeduplicationId?: null|string,
-     *   MessageGroupId?: null|string,
+     *   DelaySeconds?: int|null,
+     *   MessageAttributes?: array<string, MessageAttributeValue|array>|null,
+     *   MessageSystemAttributes?: array<MessageSystemAttributeNameForSends::*, MessageSystemAttributeValue|array>|null,
+     *   MessageDeduplicationId?: string|null,
+     *   MessageGroupId?: string|null,
      *   '@region'?: string|null,
      * }|SendMessageRequest $input
      *
@@ -817,9 +816,8 @@ class SqsClient extends AbstractApi
      * !
      * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
      * !
-     * ! Amazon SQS does not throw an exception or completely reject the message if it contains invalid characters. Instead,
-     * ! it replaces those invalid characters with U+FFFD before storing the message in the queue, as long as the message
-     * ! body contains at least one valid character.
+     * ! If a message contains characters outside the allowed set, Amazon SQS rejects the message and returns an
+     * ! InvalidMessageContents error. Ensure that your message body includes only valid characters to avoid this exception.
      *
      * If you don't specify the `DelaySeconds` parameter for an entry, Amazon SQS uses the default value for the queue.
      *
@@ -898,6 +896,13 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
+            case 'eusc-de-east-1':
+                return [
+                    'endpoint' => 'https://sqs.eusc-de-east-1.amazonaws.eu',
+                    'signRegion' => 'eusc-de-east-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
             case 'fips-ca-central-1':
                 return [
                     'endpoint' => 'https://sqs-fips.ca-central-1.amazonaws.com',
@@ -961,6 +966,13 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
+            case 'us-isob-west-1':
+                return [
+                    'endpoint' => 'https://sqs.us-isob-west-1.sc2s.sgov.gov',
+                    'signRegion' => 'us-isob-west-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
             case 'fips-us-iso-east-1':
             case 'us-iso-east-1':
                 return [
